<?php

/**
 * @file
 * Contains \Drupal\filelist_formatter\Plugin\field\formatter\FileListFormatter.
 *
 * @author keopx
 */

namespace Drupal\filelist_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'filelist_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "filelist_formatter",
 *   module = "filelist_formatter",
 *   label = @Translation("List"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class FileListFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'filelist_formatter_type' => 'ul',
      'filelist_formatter_class' => 'file-list',
        ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, array &$form_state) {
    $element = array();
    $settings = $this->getSettings();

    $element['filelist_formatter_type'] = array(
      '#title' => t('List type'),
      '#type' => 'select',
      '#options' => array(
        'ul' => t('Unordered HTML list (ul)'),
        'ol' => t('Ordered HTML list (ol)'),
      ),
      '#default_value' => $settings['filelist_formatter_type'],
      '#required' => TRUE,
    );
    $element['filelist_formatter_class'] = array(
      '#title' => t('List classes'),
      '#type' => 'textfield',
      '#size' => 40,
      '#description' => t('A CSS class to use in the markup for the field list.'),
      '#default_value' => $settings['filelist_formatter_class'],
      '#required' => FALSE,
    );

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();
    $settings = $this->getSettings();

    switch ($settings['filelist_formatter_type']) {
      case 'ul':
        $summary[] = t('Unordered HTML list');
        break;

      case 'ol':
        $summary[] = t('Ordered HTML list');
        break;
    }

    if ($settings['filelist_formatter_class']) {
      $summary[] = t('CSS Class') . ': <em>' . check_plain($settings['filelist_formatter_class']) . '</em>';
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items) {
    $elements = array();
    $settings = $this->getSettings();

    if (!$items->isEmpty()) {
      foreach ($items as $delta => $item) {
        if ($item->isDisplayed() && $item->entity) {
          $elements[$delta] = array(
            '#theme' => 'file_link',
            '#file' => $item->entity,
            '#description' => $item->description,
          );
          // Pass field item attributes to the theme function.
          if (isset($item->_attributes)) {
            $elements[$delta] += array('#attributes' => array());
            $elements[$delta]['#attributes'] += $item->_attributes;
            // Unset field item attributes since they have been included in the
            // formatter output and should not be rendered in the field template.
            unset($item->_attributes);
          }
        }
      }
      $classes = explode(' ', $settings['filelist_formatter_class']);

      $elements = array(
        '#theme' => 'item_list',
        '#items' => $elements,
        '#list_type' => $settings['filelist_formatter_type'],
        '#attributes' => array(
          'class' => $classes,
        ),
      );
    }

    return $elements;
  }

}
